@@ -39,7 +39,7 @@ from maleo.schemas.exception.exc import (
     InternalServerError,
     ServiceUnavailable,
 )
-from maleo.schemas.exception.factory import Factory as MaleoExceptionFactory
+from maleo.schemas.exception.factory import MaleoExceptionFactory
 from maleo.schemas.google import ListOfPublisherHandlers
 from maleo.schemas.operation.action.system import SystemOperationAction
 from maleo.schemas.operation.context import generate
@@ -197,7 +197,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="IntegrityError occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from ie
@@ -212,7 +212,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="OperationalError occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from oe
@@ -227,7 +227,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="ProgrammingError occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from pe
@@ -242,7 +242,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="DatabaseError occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from de
@@ -257,7 +257,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="SQLAlchemyError occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from se
@@ -271,7 +271,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="ValidationError occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from ve
@@ -286,7 +286,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="HTTPException occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from he
@@ -294,7 +294,7 @@ class SessionManager(Generic[SQLConfigT]):
                     raise he
         except MaleoException as me:
             await session.rollback()
-            me.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            me.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 raise me
         except Exception as e:
@@ -314,7 +314,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="Unexpected error occured while handling async database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from e
@@ -404,7 +404,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="IntegrityError occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from ie
@@ -419,7 +419,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="OperationalError occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from oe
@@ -434,7 +434,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="ProgrammingError occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from pe
@@ -449,7 +449,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="DatabaseError occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from de
@@ -464,7 +464,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="SQLAlchemyError occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from se
@@ -478,7 +478,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="ValidationError occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from ve
@@ -493,7 +493,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="HTTPException occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from he
@@ -501,7 +501,7 @@ class SessionManager(Generic[SQLConfigT]):
                     raise he
         except MaleoException as me:
             session.rollback()
-            me.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            me.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 raise me
         except Exception as e:
@@ -521,7 +521,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_timestamp=Timestamp.completed_now(executed_at),
                 operation_summary="Unexpected error occured while handling sync database session",
             )
-            exc.log_and_publish_operation(self._logger, Level.ERROR, self._publishers)
+            exc.log_and_publish_operation(self._logger, self._publishers)
             if raise_exc:
                 if raise_as_maleo_exception:
                     raise exc from e
